@@ -15,7 +15,7 @@ from .plugins import plugin_manager
 from .sessions import DEFAULT_SESSIONS_DIR
 from .output import AVAILABLE_STYLES, DEFAULT_STYLE
 from .input import (Parser, AuthCredentialsArgType, KeyValueArgType,
-                    SEP_PROXY, SEP_CREDENTIALS, SEP_GROUP_ITEMS,
+                    SEP_PROXY, SEP_CREDENTIALS, SEP_GROUP_ALL_ITEMS,
                     OUT_REQ_HEAD, OUT_REQ_BODY, OUT_RESP_HEAD,
                     OUT_RESP_BODY, OUTPUT_OPTIONS, OUTPUT_OPTIONS_DEFAULT,
                     PRETTY_MAP, PRETTY_STDOUT_TTY_ONLY, SessionNameValidator)
@@ -88,13 +88,18 @@ positional.add_argument(
     help="""
     The scheme defaults to 'http://' if the URL does not include one.
 
+    You can also use a shorthand for localhost
+
+        $ http :3000                    # => http://localhost:3000
+        $ http :/foo                    # => http://localhost/foo
+
     """
 )
 positional.add_argument(
     'items',
-    metavar='REQUEST ITEM',
+    metavar='REQUEST_ITEM',
     nargs=ZERO_OR_MORE,
-    type=KeyValueArgType(*SEP_GROUP_ITEMS),
+    type=KeyValueArgType(*SEP_GROUP_ALL_ITEMS),
     help=r"""
     Optional key-value pairs to be included in the request. The separator used
     determines the type:
@@ -112,13 +117,21 @@ positional.add_argument(
 
         name=HTTPie  language=Python  description='CLI HTTP client'
 
+    ':=' Non-string JSON data fields (only with --json, -j):
+
+        awesome:=true  amount:=42  colors:='["red", "green", "blue"]'
+
     '@' Form file fields (only with --form, -f):
 
         cs@~/Documents/CV.pdf
 
-    ':=' Non-string JSON data fields (only with --json, -j):
+    '=@' A data field like '=', but takes a file path and embeds its content:
 
-        awesome:=true  amount:=42  colors:='["red", "green", "blue"]'
+         essay=@Documents/essay.txt
+
+    ':=@' A raw JSON field like ':=', but takes a file path and embeds its content:
+
+        package:=@./package.json
 
     You can use a backslash to escape a colliding separator in the field name:
 
@@ -186,7 +199,7 @@ output_processing.add_argument(
     default=DEFAULT_STYLE,
     choices=AVAILABLE_STYLES,
     help="""
-    Output coloring style (default is "{default}"). On of:
+    Output coloring style (default is "{default}"). One of:
 
 {available}
 
@@ -422,11 +435,12 @@ network.add_argument(
     '--proxy',
     default=[],
     action='append',
-    metavar='PROTOCOL:HOST',
+    metavar='PROTOCOL:PROXY_URL',
     type=KeyValueArgType(SEP_PROXY),
     help="""
-    String mapping protocol to the URL of the proxy (e.g. http:foo.bar:3128).
-    You can specify multiple proxies with different protocols.
+    String mapping protocol to the URL of the proxy
+    (e.g. http:http://foo.bar:3128). You can specify multiple proxies with
+    different protocols.
 
     """
 )
